package App::GenPericmdScript;

our $DATE = '2020-04-30'; # DATE
our $VERSION = '0.230'; # VERSION

use 5.010001;

1;
# ABSTRACT: Generate Perinci::CmdLine CLI script (CLI)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::GenPericmdScript - Generate Perinci::CmdLine CLI script (CLI)

=head1 VERSION

This document describes version 0.230 of App::GenPericmdScript (from Perl distribution App-GenPericmdScript), released on 2020-04-30.

=head1 SYNOPSIS

See L<gen-pericmd-script>.

=head1 DESCRIPTION

This distribution provides CLI for L<Perinci::CmdLine::Gen>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-GenPericmdScript>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-GenPericmdScript>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-GenPericmdScript>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
